@@ -4,10 +4,12 @@
 """
 Pytube: a very serious Python library for downloading YouTube Videos.
 """
-__title__ = "pytube3"
+__title__ = "pytube"
 __author__ = "Nick Ficano, Harold Martin"
 __license__ = "MIT License"
 __copyright__ = "Copyright 2019 Nick Ficano"
+__js__ = None
+__js_url__ = None
 
 from pytube.version import __version__
 from pytube.streams import Stream
