@@ -18,10 +18,12 @@ from urllib.parse import unquote
 from urllib.parse import urlencode
 
 from pytube.cipher import Cipher
+from pytube.exceptions import HTMLParseError
 from pytube.exceptions import LiveStreamError
 from pytube.exceptions import RegexMatchError
 from pytube.helpers import regex_search
 from pytube.metadata import YouTubeMetadata
+from pytube.parser import parse_for_object
 
 logger = logging.getLogger(__name__)
 
@@ -98,6 +100,58 @@ def is_age_restricted(watch_html: str) -> bool:
     return True
 
 
+def is_region_blocked(watch_html: str) -> bool:
+    """Determine if a video is not available in the user's region.
+
+    :param str watch_html:
+        The html contents of the watch page.
+    :rtype: bool
+    :returns:
+        True if the video is blocked in the users region.
+        False if not, or if unknown.
+    """
+    player_response = initial_player_response(watch_html)
+    country_code_patterns = [
+        r"gl\s*=\s*['\"](\w{2})['\"]",  # gl="US"
+        r"['\"]gl['\"]\s*:\s*['\"](\w{2})['\"]"  # "gl":"US"
+    ]
+    for pattern in country_code_patterns:
+        try:
+            yt_detected_country = regex_search(pattern, watch_html, 1)
+            available_countries = player_response[
+                'microformat']['playerMicroformatRenderer']['availableCountries']
+        except (KeyError, RegexMatchError):
+            pass
+        else:
+            if yt_detected_country not in available_countries:
+                return True
+    return False
+
+
+def playability_status(watch_html: str) -> (str, str):
+    """Return the playability status and status explanation of a video.
+
+    For example, a video may have a status of LOGIN_REQUIRED, and an explanation
+    of "This is a private video. Please sign in to verify that you may see it."
+
+    This explanation is what gets incorporated into the media player overlay.
+
+    :param str watch_html:
+        The html contents of the watch page.
+    :rtype: bool
+    :returns:
+        Playability status and reason of the video.
+    """
+    player_response = initial_player_response(watch_html)
+    status_dict = player_response.get('playabilityStatus', {})
+    if 'status' in status_dict:
+        if 'reason' in status_dict:
+            return status_dict['status'], [status_dict['reason']]
+        if 'messages' in status_dict:
+            return status_dict['status'], status_dict['messages']
+    return None, [None]
+
+
 def video_id(url: str) -> str:
     """Extract the ``video_id`` from a YouTube url.
 
@@ -269,31 +323,31 @@ def get_ytplayer_config(html: str) -> Any:
     """
     logger.debug("finding initial function name")
     config_patterns = [
-        r"ytplayer\.config\s*=\s*({.+?});ytplayer",
-        r"ytInitialPlayerResponse\s*=\s*({.+?(?<!gdpr)});"
+        r"ytplayer\.config\s*=\s*",
+        r"ytInitialPlayerResponse\s*=\s*"
     ]
     for pattern in config_patterns:
-        regex = re.compile(pattern)
-        function_match = regex.search(html)
-        if function_match:
-            logger.debug("finished regex search, matched: %s", pattern)
-            yt_player_config = function_match.group(1)
-            return json.loads(yt_player_config)
+        # Try each pattern consecutively if they don't find a match
+        try:
+            return parse_for_object(html, pattern)
+        except HTMLParseError as e:
+            logger.debug(f'Pattern failed: {pattern}')
+            logger.debug(e)
+            continue
 
     # setConfig() needs to be handled a little differently.
     # We want to parse the entire argument to setConfig()
     #  and use then load that as json to find PLAYER_CONFIG
     #  inside of it.
     setconfig_patterns = [
-        r"yt\.setConfig\((.*['\"]PLAYER_CONFIG['\"]:\s*{.+?})\);"
+        r"yt\.setConfig\(.*['\"]PLAYER_CONFIG['\"]:\s*"
     ]
     for pattern in setconfig_patterns:
-        regex = re.compile(pattern)
-        function_match = regex.search(html)
-        if function_match:
-            logger.debug("finished regex search, matched: %s", pattern)
-            yt_config = function_match.group(1)
-            return json.loads(yt_config)['PLAYER_CONFIG']
+        # Try each pattern consecutively if they don't find a match
+        try:
+            return parse_for_object(html, pattern)
+        except HTMLParseError:
+            continue
 
     raise RegexMatchError(
         caller="get_ytplayer_config", pattern="config_patterns, setconfig_patterns"
@@ -374,7 +428,7 @@ def apply_descrambler(stream_data: Dict, key: str) -> None:
         if isinstance(stream_data["player_response"], str):
             streaming_data = json.loads(stream_data["player_response"])["streamingData"]
         else:
-            streaming_data = stream_data["player_response"]
+            streaming_data = stream_data["player_response"]["streamingData"]
         formats = []
         if 'formats' in streaming_data.keys():
             formats.extend(streaming_data['formats'])
@@ -431,11 +485,42 @@ def initial_data(watch_html: str) -> str:
     @param watch_html: Html of the watch page
     @return:
     """
-    initial_data_pattern = r"window\[['\"]ytInitialData['\"]]\s*=\s*([^\n]+);"
-    try:
-        return regex_search(initial_data_pattern, watch_html, 1)
-    except RegexMatchError:
-        return "{}"
+    patterns = [
+        r"window\[['\"]ytInitialData['\"]]\s*=\s*",
+        r"ytInitialData\s*=\s*"
+    ]
+    for pattern in patterns:
+        try:
+            return parse_for_object(watch_html, pattern)
+        except HTMLParseError:
+            pass
+
+    raise RegexMatchError(caller='initial_data', pattern='initial_data_pattern')
+
+
+def initial_player_response(watch_html: str) -> str:
+    """Extract the ytInitialPlayerResponse json from the watch_html page.
+
+    This mostly contains metadata necessary for rendering the page on-load,
+    such as video information, copyright notices, etc.
+
+    @param watch_html: Html of the watch page
+    @return:
+    """
+    patterns = [
+        r"window\[['\"]ytInitialPlayerResponse['\"]]\s*=\s*",
+        r"ytInitialPlayerResponse\s*=\s*"
+    ]
+    for pattern in patterns:
+        try:
+            return parse_for_object(watch_html, pattern)
+        except HTMLParseError:
+            pass
+
+    raise RegexMatchError(
+        caller='initial_player_response',
+        pattern='initial_player_response_pattern'
+    )
 
 
 def metadata(initial_data) -> Optional[YouTubeMetadata]:
