@@ -72,6 +72,13 @@ def missing_recording():
     return load_playback_file(filename)
 
 
+@pytest.fixture
+def region_blocked():
+    """Youtube instance initialized with video id hZpzr8TbF08."""
+    filename = "yt-video-hZpzr8TbF08-html.json.gz"
+    return load_playback_file(filename)
+
+
 @pytest.fixture
 def playlist_html():
     """Youtube playlist HTML loaded on 2020-01-25 from
