@@ -7,9 +7,9 @@ import pytest
     ("test_input", "expected"),
     [
         ({"progressive": True}, [18, 22]),
-        ({"resolution": "720p"}, [22, 136, 247]),
-        ({"res": "720p"}, [22, 136, 247]),
-        ({"fps": 30, "resolution": "480p"}, [135, 244]),
+        ({"resolution": "720p"}, [22, 136, 247, 398]),
+        ({"res": "720p"}, [22, 136, 247, 398]),
+        ({"fps": 30, "resolution": "480p"}, [135, 244, 397]),
         ({"mime_type": "audio/mp4"}, [140]),
         ({"type": "audio"}, [140, 249, 250, 251]),
         ({"subtype": "3gpp"}, []),
@@ -19,7 +19,7 @@ import pytest
         ({"video_codec": "vp9"}, [248, 247, 244, 243, 242, 278]),
         ({"only_audio": True}, [140, 249, 250, 251]),
         ({"only_video": True, "video_codec": "avc1.4d4015"}, [133]),
-        ({"adaptive": True, "resolution": "1080p"}, [137, 248]),
+        ({"adaptive": True, "resolution": "1080p"}, [137, 248, 399]),
         ({"custom_filter_functions": [lambda s: s.itag == 18]}, [18]),
     ],
 )
@@ -86,7 +86,7 @@ def test_order_by_non_numerical(cipher_signature):
         .order_by("mime_type")
         .desc()
     ]
-    assert mime_types == ["video/webm", "video/mp4", "video/mp4"]
+    assert mime_types == ["video/webm", "video/mp4", "video/mp4", "video/mp4"]
 
 
 def test_order_by_ascending(cipher_signature):
@@ -110,7 +110,7 @@ def test_order_by_non_numerical_ascending(cipher_signature):
         .order_by("mime_type")
         .asc()
     ]
-    assert mime_types == ["video/mp4", "video/mp4", "video/webm"]
+    assert mime_types == ["video/mp4", "video/mp4", "video/mp4", "video/webm"]
 
 
 def test_order_by_with_none_values(cipher_signature):
@@ -144,7 +144,7 @@ def test_get_highest_resolution(cipher_signature):
 def test_filter_is_dash(cipher_signature):
     streams = cipher_signature.streams.filter(is_dash=False)
     itags = [s.itag for s in streams]
-    assert itags == [18, 22, 399, 398, 397, 396, 395, 394]
+    assert itags == [18, 22]
 
 
 def test_get_audio_only(cipher_signature):
