@@ -2,8 +2,10 @@
 import os
 import random
 from datetime import datetime
+import pytest
 from unittest import mock
 from unittest.mock import MagicMock, Mock
+from urllib.error import HTTPError
 
 from pytube import request
 from pytube import Stream
@@ -40,30 +42,24 @@ def test_filesize(cipher_signature):
 def test_filesize_approx(cipher_signature):
     stream = cipher_signature.streams[0]
 
-    assert stream.filesize_approx == 22350604
+    assert stream.filesize_approx == 28309811
     stream.bitrate = None
     assert stream.filesize_approx == 6796391
 
 
 def test_default_filename(cipher_signature):
-    expected = "PSY - GANGNAM STYLE(강남스타일) MV.mp4"
+    expected = "YouTube Rewind 2019 For the Record  YouTubeRewind.mp4"
     stream = cipher_signature.streams[0]
     assert stream.default_filename == expected
 
 
 def test_title(cipher_signature):
-    expected = "title"
-    cipher_signature.player_config_args["title"] = expected
-    assert cipher_signature.title == expected
-
-    expected = "title2"
-    del cipher_signature.player_config_args["title"]
-    cipher_signature.player_response = {"videoDetails": {"title": expected}}
+    expected = "YouTube Rewind 2019: For the Record | #YouTubeRewind"
     assert cipher_signature.title == expected
 
 
 def test_expiration(cipher_signature):
-    assert cipher_signature.streams[0].expiration == datetime(2020, 10, 24, 11, 7, 41)
+    assert cipher_signature.streams[0].expiration == datetime(2020, 10, 30, 5, 39, 41)
 
 
 def test_caption_tracks(presigned_video):
@@ -76,34 +72,42 @@ def test_captions(presigned_video):
 
 def test_description(cipher_signature):
     expected = (
-        "PSY - ‘I LUV IT’ M/V @ https://youtu.be/Xvjnoagk6GU\n"
-        "PSY - ‘New Face’ M/V @https://youtu.be/OwJPPaEyqhI\n\n"
-        "PSY - 8TH ALBUM '4X2=8' on iTunes @\n"
-        "https://smarturl.it/PSY_8thAlbum\n\n"
-        "PSY - GANGNAM STYLE(강남스타일) on iTunes @ "
-        "http://smarturl.it/PsyGangnam\n\n"
-        "#PSY #싸이 #GANGNAMSTYLE #강남스타일\n\n"
-        "More about PSY@\nhttp://www.youtube.com/officialpsy\n"
-        "http://www.facebook.com/officialpsy\n"
-        "http://twitter.com/psy_oppa\n"
-        "https://www.instagram.com/42psy42\n"
-        "http://iTunes.com/PSY\n"
-        "http://sptfy.com/PSY\n"
-        "http://weibo.com/psyoppa"
+        "In 2018, we made something you didn’t like. "
+        "For Rewind 2019, let’s see what you DID like.\n\n"
+        "Celebrating the creators, music and moments "
+        "that mattered most to you in 2019. \n\n"
+        "To learn how the top lists in Rewind were generated: "
+        "https://rewind.youtube/about\n\n"
+        "Top lists featured the following channels:\n\n"
+        "@1MILLION Dance Studio \n@A4 \n@Anaysa \n"
+        "@Andymation \n@Ariana Grande \n@Awez Darbar \n"
+        "@AzzyLand \n@Billie Eilish \n@Black Gryph0n \n"
+        "@BLACKPINK \n@ChapkisDanceUSA \n@Daddy Yankee \n"
+        "@David Dobrik \n@Dude Perfect \n@Felipe Neto \n"
+        "@Fischer's-フィッシャーズ- \n@Galen Hooks \n@ibighit \n"
+        "@James Charles \n@jeffreestar \n@Jelly \n@Kylie Jenner \n"
+        "@LazarBeam \n@Lil Dicky \n@Lil Nas X \n@LOUD \n@LOUD Babi \n"
+        "@LOUD Coringa \n@Magnet World \n@MrBeast \n"
+        "@Nilson Izaias Papinho Oficial \n@Noah Schnapp\n"
+        "@백종원의 요리비책 Paik's Cuisine \n@Pencilmation \n@PewDiePie \n"
+        "@SethEverman \n@shane \n@Shawn Mendes \n@Team Naach \n"
+        "@whinderssonnunes \n@워크맨-Workman \n@하루한끼 one meal a day \n\n"
+        "To see the full list of featured channels in Rewind 2019, "
+        "visit: https://rewind.youtube/about"
     )
     assert cipher_signature.description == expected
 
 
 def test_rating(cipher_signature):
-    assert cipher_signature.rating == 4.5375643
+    assert cipher_signature.rating == 2.0860765
 
 
 def test_length(cipher_signature):
-    assert cipher_signature.length == 252
+    assert cipher_signature.length == 337
 
 
 def test_views(cipher_signature):
-    assert cipher_signature.views == 3830838693
+    assert cipher_signature.views >= 108531745
 
 
 @mock.patch(
@@ -133,7 +137,7 @@ def test_download_with_prefix(cipher_signature):
         file_path = stream.download(filename_prefix="prefix")
         assert file_path == os.path.join(
             "/target",
-            "prefixPSY - GANGNAM STYLE(강남스타일) MV.mp4"
+            "prefixYouTube Rewind 2019 For the Record  YouTubeRewind.mp4"
         )
 
 
@@ -171,7 +175,7 @@ def test_download_with_existing(cipher_signature):
         file_path = stream.download()
         assert file_path == os.path.join(
             "/target",
-            "PSY - GANGNAM STYLE(강남스타일) MV.mp4"
+            "YouTube Rewind 2019 For the Record  YouTubeRewind.mp4"
         )
         assert not request.stream.called
 
@@ -192,7 +196,7 @@ def test_download_with_existing_no_skip(cipher_signature):
         file_path = stream.download(skip_existing=False)
         assert file_path == os.path.join(
             "/target",
-            "PSY - GANGNAM STYLE(강남스타일) MV.mp4"
+            "YouTube Rewind 2019 For the Record  YouTubeRewind.mp4"
         )
         assert request.stream.called
 
@@ -264,7 +268,7 @@ def test_thumbnail_when_in_details(cipher_signature):
 
 
 def test_thumbnail_when_not_in_details(cipher_signature):
-    expected = "https://img.youtube.com/vi/9bZkp7q19f0/maxresdefault.jpg"
+    expected = "https://img.youtube.com/vi/2lAe1cqCOXo/maxresdefault.jpg"
     cipher_signature.player_response = {}
     assert cipher_signature.thumbnail_url == expected
 
@@ -304,3 +308,84 @@ def test_repr_for_adaptive_streams(cipher_signature):
         'vcodec="avc1.640028" progressive="False" type="video">'
     )
     assert stream == expected
+
+
+def test_segmented_stream_on_404(cipher_signature):
+    stream = cipher_signature.streams.filter(adaptive=True)[0]
+    with mock.patch('pytube.request.head') as mock_head:
+        with mock.patch('pytube.request.urlopen') as mock_url_open:
+            # Mock the responses to YouTube
+            mock_url_open_object = mock.Mock()
+
+            # These are our 4 "segments" of a dash stream
+            # The first explains how many pieces there are, and
+            # the rest are those pieces
+            responses = [
+                b'Raw_data\r\nSegment-Count: 3',
+                b'a',
+                b'b',
+                b'c',
+            ]
+            joined_responses = b''.join(responses)
+
+            # We create response headers to match the segments
+            response_headers = [
+                {
+                    'content-length': len(r),
+                    'Content-Range': '0-%s/%s' % (str(len(r)), str(len(r)))
+                }
+                for r in responses
+            ]
+
+            # Request order for stream:
+            # Filesize:
+            #   1. head(url) -> 404
+            #   2. get(url&sn=0)
+            #   3. head(url&sn=[1,2,3])
+            # Download:
+            #   4. info(url) -> 404
+            #   5. get(url&sn=0)
+            #   6. get(url&sn=[1,2,3])
+
+            # Handle filesize requests
+            mock_head.side_effect = [
+                HTTPError('', 404, 'Not Found', '', ''),
+                *response_headers[1:],
+            ]
+
+            # Each response must be followed by None, to break iteration
+            #  in the stream() function
+            mock_url_open_object.read.side_effect = [
+                responses[0], None,
+                responses[0], None,
+                responses[1], None,
+                responses[2], None,
+                responses[3], None,
+            ]
+
+            # This handles the HEAD requests to get content-length
+            mock_url_open_object.info.side_effect = [
+                HTTPError('', 404, 'Not Found', '', ''),
+                *response_headers
+            ]
+
+            mock_url_open.return_value = mock_url_open_object
+
+            with mock.patch('builtins.open', new_callable=mock.mock_open) as mock_open:
+                file_handle = mock_open.return_value.__enter__.return_value
+                fp = stream.download()
+                full_content = b''
+                for call in file_handle.write.call_args_list:
+                    args, kwargs = call
+                    full_content += b''.join(args)
+
+                assert full_content == joined_responses
+                mock_open.assert_called_once_with(fp, 'wb')
+
+
+def test_segmented_only_catches_404(cipher_signature):
+    stream = cipher_signature.streams.filter(adaptive=True)[0]
+    with mock.patch('pytube.request.head') as mock_head:
+        mock_head.side_effect = HTTPError('', 403, 'Forbidden', '', '')
+        with pytest.raises(HTTPError):
+            stream.download()
